Package: MetaPathNet
Title: KEGG-Based Metabolic and Signaling Network Analysis for Systems
        Biology
Version: 0.99.5
Authors@R: c(
    person(
        "Zhaojie", "Wang",
        email = "zhaojie.wang@cnrs.fr",
        role = c("aut", "cre"),
        comment = c(ORCID = "0009-0009-7191-2107")
    ),
    person("Francesc", "Puig-Castellvi", role = "aut"),
    person("Manyi", "Jia", role = "aut"),
    person("Marc-Emmanuel", "Dumas", role = c("aut", "ths")),
    person("Centre National de la Recherche Scientifique", role = "fnd"),
    person("Imperial College London", role = "fnd"),
    person("French National Research Agency", role = "fnd")
    )
Description: Provides tools to construct KEGG-based metabolic and
    signaling networks as edge lists for single-organism or cross-species
    analyses. The package supports identifier mapping, shortest-path and
    topology analyses, community detection, permutation testing, pathway
    over-representation analysis, and node annotation for host-microbiome
    studies. It also provides network visualisation in R and Cytoscape and
    supports extension of KEGG-based networks through additional reaction
    resources and user-defined reactions.
Depends: R (>= 4.6.0)
Imports: igraph, httr, utils, RCurl, RCy3, tidygraph, ggraph, dplyr,
        KEGGREST, KEGGgraph, graph, mygene, ggplot2, rlang, curl,
        jsonlite, webchem, grDevices, grid, stats
Suggests: testthat, knitr, rmarkdown, BiocStyle
SystemRequirements: Cytoscape (>= 3.9.0) for Cytoscape-based
        visualisation functions
biocViews: Network, Pathways, KEGG, SystemsBiology, Classification,
        Microbiome
License: MIT + file LICENSE
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
VignetteBuilder: knitr
URL: https://github.com/zhaojie-wang/MetaPathNet
BugReports: https://github.com/zhaojie-wang/MetaPathNet/issues
Config/roxygen2/version: 8.0.0
git_url: https://git.bioconductor.org/packages/MetaPathNet
git_branch: devel
git_last_commit: fdaae4d
git_last_commit_date: 2026-07-28
Repository: Bioconductor 3.24
Date/Publication: 2026-07-31
NeedsCompilation: no
Packaged: 2026-07-31 22:47:27 UTC; biocbuild
Author: Zhaojie Wang [aut, cre] (ORCID:
    <https://orcid.org/0009-0009-7191-2107>),
  Francesc Puig-Castellvi [aut],
  Manyi Jia [aut],
  Marc-Emmanuel Dumas [aut, ths],
  Centre National de la Recherche Scientifique [fnd],
  Imperial College London [fnd],
  French National Research Agency [fnd]
Maintainer: Zhaojie Wang <zhaojie.wang@cnrs.fr>
